!---------------------------------------------------------------------------------------
! GRID_TO_NCDF: grid_convert
!---------------------------------------------------------------------------------------
!  FLEXINVERT is free software: you can redistribute it and/or modify
!  it under the terms of the GNU General Public License as published by
!  the Free Software Foundation, either version 3 of the License, or
!  (at your option) any later version.
!
!  FLEXINVERT is distributed in the hope that it will be useful,
!  but WITHOUT ANY WARRANTY; without even the implied warranty of
!  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!  GNU General Public License for more details.
!
!  You should have received a copy of the GNU General Public License
!  along with FLEXINVERT.  If not, see <http://www.gnu.org/licenses/>.
!
!  Copyright 2017, Rona Thompson
!---------------------------------------------------------------------------------------
!
!> grid_convert
!! 
!! Purpose:    
!!
!---------------------------------------------------------------------------------------

subroutine grid_convert(files, config)

  use mod_var
  use mod_settings
  use mod_flexpart
  use mod_dates

  implicit none

  type (files_t),  intent(in out)        :: files
  type (config_t), intent(in)            :: config

  character(max_path_len)                                :: filename, filedates
  character(len=max_path_len), dimension(:), allocatable :: filelist
  character(len=8)                                       :: adate
  character(len=6)                                       :: atime
  integer                                                :: nfiles, i, ierr, n
  integer                                                :: jjjjmmdd, hhmiss 
  real, dimension(nxgrid,nygrid,ngrid)                   :: grid
  real(kind=8), dimension(ngrid)                         :: gtime, time
  real(kind=8)                                           :: jdate

  ! list all grid files in directory
  if ( config%lnested ) then
    call system('ls '//trim(files%path_flexpart)//' | grep grid_time_nest | wc -l > '//trim(files%path_output)//'files.txt')
    call system('ls '//trim(files%path_flexpart)//' | grep grid_time_nest  >> '//trim(files%path_output)//'files.txt')
  else
    call system('ls '//trim(files%path_flexpart)//' -I "*nest*" | grep grid_time | wc -l > '//trim(files%path_output)//'files.txt')
    call system('ls '//trim(files%path_flexpart)//' -I "*nest*" | grep grid_time >> '//trim(files%path_output)//'files.txt')
  endif

  ! read file list
  open(100,file=trim(files%path_output)//'files.txt',status="old",action="read",iostat=ierr)
  if ( ierr.ne.0 ) then
    print*, 'ERROR: problem read files.txt'
    stop
  endif
  read(100,*) nfiles
  allocate( filelist(nfiles) ) 
  do i = 1, nfiles
    read(100,fmt='(A)',iostat=ierr) filelist(i)
    if (ierr.ne.0) exit
  end do
  close(100)

  ! loop over files
  filedates = trim(files%path_flexpart)//'dates'
  do i = 1, nfiles
    ! read binary grid files
    if ( config%lnested ) then
      adate = filelist(i)(16:23)
      atime = filelist(i)(24:29)
    else
      adate = filelist(i)(11:18)
      atime = filelist(i)(19:24)
    endif
    print*, 'adate = ',adate
    print*, 'atime = ',atime
    read(adate,*) jjjjmmdd
    read(atime,*) hhmiss
    print*, 'jjjjmmdd = ',jjjjmmdd
    print*, 'hhmiss = ',hhmiss
    if ( config%linversionout ) then
      jdate = juldate(jjjjmmdd, hhmiss)
    else
      jdate = juldate(datei,timei)
    endif
    print*, 'jdate = ',jdate
    filename = trim(files%path_flexpart)//trim(filelist(i))
    if ( config%linversionout ) then
      call read_grid(config, filename, filedates, jdate, nxgrid, nygrid, grid, gtime)
    else
      call read_grid_std(config, filename, jdate, nxgrid, nygrid, grid, gtime)
    endif
    print*, 'gtime = ',gtime
    ! write to ncdf
    do n = 1, ngrid
      call caldate(gtime(n), jjjjmmdd, hhmiss)
      time(n) = real(jjjjmmdd,kind=8)*100d0+real(hhmiss/10000,kind=8)
    end do
    print*, 'time = ',time
    if ( config%lnested ) then
      filename = trim(files%path_output)//'grid_time_nest_'//adate//atime//'_001.nc'
    else
      filename = trim(files%path_output)//'grid_time_'//adate//atime//'_001.nc'
    endif
    call write_ncdf(filename, time, grid)
  end do  


end subroutine grid_convert

