!---------------------------------------------------------------------------------------
! GRID_TO_NCDF: mod_var
!---------------------------------------------------------------------------------------
!  FLEXINVERT is free software: you can redistribute it and/or modify
!  it under the terms of the GNU General Public License as published by
!  the Free Software Foundation, either version 3 of the License, or
!  (at your option) any later version.
!
!  FLEXINVERT is distributed in the hope that it will be useful,
!  but WITHOUT ANY WARRANTY; without even the implied warranty of
!  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!  GNU General Public License for more details.
!
!  You should have received a copy of the GNU General Public License
!  along with FLEXINVERT.  If not, see <http://www.gnu.org/licenses/>.
!
!  Copyright 2017, Rona Thompson
!---------------------------------------------------------------------------------------
!
!> mod_var
!! 
!!
!---------------------------------------------------------------------------------------

module mod_var

  implicit none

  ! fixed parameters 
  ! -----------------

  integer, parameter :: max_path_len=200         ! max character length of paths and files
  integer, parameter :: max_name_len=50          ! max character length of variable names
  integer, parameter :: maxpoint=1000            ! max number of releases per receptor per month
  integer, parameter :: maxspec=10               ! max number of species in a flexpart run
  integer, parameter :: maxlev=50                ! max number of vertical levels in flexpart output
  integer, parameter :: maxobs=10000             ! max number of observations

  ! flexpart variables 
  ! ------------------

  integer            :: ageclass                 ! length of backtrajectories (s)
  integer            :: trajdays                 ! length of backtrajectories (days)
  integer            :: ndgrid                   ! number of footprints per day
  integer            :: ngrid                    ! number of footprints (ndgrid*trajdays)
  integer            :: nxgrid                   ! number of longitudinal grid cells
  integer            :: nygrid                   ! number of latitudinal grid cells
  integer            :: nzgrid                   ! number of vertical layers in grid_init files
  integer            :: nzlev                    ! number of vertical layers in grid_time files (nzlev = 1)
  real               :: llx                      ! lower right longitude of flexpart grid
  real               :: lly                      ! lower right latitude of flexpart grid
  real               :: dx                       ! longitudinal resolution of flexpart grid
  real               :: dy                       ! latitudinal resolution of flexpart grid
  integer            :: nxshift                  ! longitudinal offset in grid cells relative to 180W for global output
  real, dimension(maxlev) :: outheight           ! height of model layers for grid_init files (m)
  real, dimension(:), allocatable :: glon        ! longitudes of flexpart domain
  real, dimension(:), allocatable :: glat        ! latitudes of flexpart domain
  real(kind=8), dimension(:), allocatable :: reltime ! release times
  integer            :: datei                    ! start date of run
  integer            :: timei                    ! start time of run

end module mod_var
