!---------------------------------------------------------------------------------------
! PREP_SYNDATA: get_error_cov
!---------------------------------------------------------------------------------------
!  FLEXINVERT is free software: you can redistribute it and/or modify
!  it under the terms of the GNU General Public License as published by
!  the Free Software Foundation, either version 3 of the License, or
!  (at your option) any later version.
!
!  FLEXINVERT is distributed in the hope that it will be useful,
!  but WITHOUT ANY WARRANTY; without even the implied warranty of
!  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!  GNU General Public License for more details.
!
!  You should have received a copy of the GNU General Public License
!  along with FLEXINVERT.  If not, see <http://www.gnu.org/licenses/>.
!
!  Copyright 2017, Rona Thompson
!---------------------------------------------------------------------------------------
!
!> get_error_cov
!!
!! Purpose:    Reads the eigen values and vectors as well as temporal covariance
!!             matrix from an existing FLEXINVERT run.
!!
!---------------------------------------------------------------------------------------

subroutine get_error_cov(files)

  use mod_var
  use mod_settings

  implicit none

  type(files_t),                    intent(in)     :: files

  character(len=max_path_len)                      :: filename
  character(len=max_path_len)                      :: rowfmt
  logical                                          :: lexist
  integer                                          :: ierr, i
  real                                             :: tmp

  ! get number of eigen-values
  ! --------------------------

  filename = trim(files%path_output)//'evals.txt'
  inquire(file=trim(filename),exist=lexist)
  if (.not.lexist) then
    write(logid,*) 'ERROR: cannot find '//trim(filename)
    stop
  endif

  open(100, file=trim(filename), action='read', status='old')
  ierr = 0
  neig = 0
  do while (ierr.eq.0)  
    read(100,*,iostat=ierr) tmp
    neig = neig + 1
  end do
  close(100)
  neig = neig - 1
  print*, 'neig = ',neig

  allocate ( evals(neig) )
  allocate ( evecs(ndvar,neig) )

  ! read eigen-values
  ! -----------------

  open(100, file=trim(filename), action='read', status='old')
  do i = 1, neig 
    read(100,*) evals(i) 
  end do
  close(100)  

  ! read eigen-vectors
  ! ------------------

  filename = trim(files%path_output)//'evecs.txt'
  inquire(file=trim(filename),exist=lexist)
  if (.not.lexist) then
    write(logid,*) 'ERROR: cannot find '//trim(filename)
    stop
  endif

  write(rowfmt,'(A,I6,A)') '(',neig,'(E11.4,1X))'
  open(100, file=trim(filename), action='read', status='old')
  do i = 1, ndvar
    read(100,fmt=rowfmt) evecs(i,:)
  end do
  close(100)

  ! read temporal correlations
  ! --------------------------

  ! state vector times
  allocate( stat_time(ntstate) )
  do i = 1, ntstate
    stat_time(i) = juldatei + (i-1)*statres
  end do

  allocate ( cort(ntstate,ntstate) )
  filename = trim(files%path_output)//'cort.txt'
  inquire(file=trim(filename),exist=lexist)
  if (.not.lexist) then
    write(logid,*) 'ERROR: cannot find '//trim(filename)
    stop
  endif

  write(rowfmt,'(A,I6,A)') '(',ntstate,'(E11.4,1X))'
  open(100, file=trim(filename), action='read', status='old')
  do i = 1, ntstate
    read(100,fmt=rowfmt) cort(i,:)
  end do
  close(100)  

end subroutine get_error_cov

